@@ -24,11 +24,11 @@ unset SRCEXCLUDE        || true
 unset NORECOMMENDS      || true
 unset NOSUGGESTS        || true
 unset DOJIGDO           || true
-unset JIGDOCMD          || true
 unset JIGDOTEMPLATEURL  || true
 unset JIGDOFALLBACKURLS || true
 unset JIGDOINCLUDEURLS  || true
 unset JIGDOSCRIPT       || true
+unset JIGDO_OPTS        || true
 unset DEFBINSIZE        || true
 unset DEFSRCSIZE        || true
 unset FASTSUMS          || true
@@ -40,7 +40,6 @@ unset UDEB_EXCLUDE      || true
 unset BASE_INCLUDE      || true
 unset BASE_EXCLUDE      || true
 unset INSTALLER_CD      || true
-unset DI_CODENAME       || true
 unset MAXCDS            || true
 unset SPLASHPNG         || true
 unset OMIT_MANUAL	    || true
@@ -50,7 +49,7 @@ unset OMIT_RELEASE_NOTES || true
 # Where I am (hoping I'm in the debian-cd dir)
 export BASEDIR=`pwd`
 
-# Building sarge cd set ...
+# Building etch cd set ...
 export CODENAME=sarge
 
 # By default use Debian installer packages from $CODENAME
@@ -84,7 +83,7 @@ export ARCH=`dpkg --print-architecture`
 #	      images, however. Also, if you are using an NFS partition for
 #	      some part of this, you must use this option.
 # Paths to the mirrors
-export MIRROR=/ftp/debian
+export MIRROR=/mirror/debian
 
 # Comment the following line if you don't have/want non-US
 #export NONUS=/ftp/debian-non-US
@@ -95,14 +94,14 @@ export MIRROR=/ftp/debian
 #export FORCENONUSONCD1=1
 
 # Path of the temporary directory
-export TDIR=/ftp/tmp
+export TDIR=/mirror/tmp
 
 # Path where the images will be written
-export OUT=/rack/debian-cd
+export OUT=/mirror/debian-cd-test
 
 # Where we keep the temporary apt stuff.
 # This cannot reside on an NFS mount.
-export APTTMP=/ftp/tmp/apt
+export APTTMP=/mirror/tmp/apt
 
 # Do I want to have NONFREE merged in the CD set
 # export NONFREE=1
@@ -145,7 +144,7 @@ export CONTRIB=1
 # export COPYLINK=1
 
 # Options
-# export MKISOFS=/usr/bin/mkisofs
+# export MKISOFS=mkisofs
 # export MKISOFS_OPTS="-r"		#For normal users
 # export MKISOFS_OPTS="-r -F ."	#For symlink farmers
 
@@ -153,11 +152,11 @@ export CONTRIB=1
 export ISOLINUX=1
 
 # uncomment this to if you want to see more of what the Makefile is doing
-#export VERBOSE_MAKE=1
+export VERBOSE_MAKE=1
 
 # uncoment this to make build_all.sh try to build a simple CD image if
 # the proper official CD run does not work
-#ATTEMPT_FALLBACK=yes
+ATTEMPT_FALLBACK=yes
 
 # Set your disk size here in MB. Used in calculating package and
 # source file layouts in build.sh and build_all.sh. Defaults are for
@@ -166,9 +165,9 @@ export DEFBINSIZE=630
 export DEFSRCSIZE=635
 
 # We don't want certain packages to take up space on CD1...
-export EXCLUDE="$BASEDIR"/tasks/exclude-$CODENAME
+#export EXCLUDE="$BASEDIR"/tasks/exclude-$CODENAME
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included on CD >= x)
-export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
+#export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
 # Any packages listed in EXCLUDE but not in any UNEXCLUDE will be
 # excluded completely.
 
@@ -234,7 +233,7 @@ export JIGDOINCLUDEURLS="http://cdimage.debian.org/debian-cd/debian-servers.jigd
 
 # If set, use the md5sums from the main archive, rather than calculating
 # them locally
-#export FASTSUMS=1
+export FASTSUMS=1
 
 # A couple of things used only by publish_cds, so it can tweak the
 # jigdo files, and knows where to put the results.
@@ -243,6 +242,31 @@ export PUBLISH_URL="http://cdimage.debian.org/jigdo-area"
 export PUBLISH_NONUS_URL="http://non-US.cdimage.debian.org/jigdo-area"
 export PUBLISH_PATH="/home/jigdo-area/"
 
+# Specify files and directories to *exclude* from jigdo processing. These
+# files on each CD are expected to be different to those on the mirror, or
+# are often subject to change. Any files matching entries in this list will
+# simply be placed straight into the template file.
+export JIGDO_EXCLUDE="'README*' /doc/ /md5sum.txt /.disk/ /pics/ 'Release*' 'Packages*' 'Sources*'"
+
+# Specify files that MUST match entries in the externally-supplied
+# md5-list. If they do not, the CD build process will fail; something
+# must have been corrupted. Replaces the old mirrorcheck code.
+export JIGDO_INCLUDE="/pool/"
+
+# Specify the minimum file size to consider for jigdo processing. Any files
+# smaller than this will simply be placed straight into the template file.
+export JIGDO_OPTS="-jigdo-min-file-size 0"
+
+for EXCL in $JIGDO_EXCLUDE
+do
+    JIGDO_OPTS="$JIGDO_OPTS -jigdo-exclude $EXCL"
+done
+
+for INCL in $JIGDO_INCLUDE
+do
+    JIGDO_OPTS="$JIGDO_OPTS -jigdo-force-md5 $INCL"
+done
+
 # Where to find the boot disks
 #export BOOTDISKS=$TOPDIR/ftp/skolelinux/boot-floppies
 
@@ -269,14 +293,14 @@ export PUBLISH_PATH="/home/jigdo-area/"
 # INSTALLER_CD=0: nothing special (default)
 # INSTALLER_CD=1: just add debian-installer (use TASK=tasks/debian-installer-$CODENAME)
 # INSTALLER_CD=2: add d-i and base (use TASK=tasks/debian-installer+kernel-$CODENAME)
-#export INSTALLER_CD=0
+#export INSTALLER_CD=2
 
 # Parameters to pass to kernel when the CD boots. Not currently supported
 # for all architectures.
 #export KERNEL_PARAMS="DEBCONF_PRIORITY=critical"
 
 # If set, limits the number of binary CDs to produce.
-#export MAXCDS=1
+# export MAXCDS=1
 
 # If set, overrides the boot picture used.
 #export SPLASHPNG="$BASEDIR/data/$CODENAME/splash-img.png"
@@ -284,7 +308,7 @@ export PUBLISH_PATH="/home/jigdo-area/"
 # Used by build.sh to determine what to build, this is the name of a target
 # in the Makefile. Use bin-official_images to build only binary CDs. The
 # default, official_images, builds everything.
-#IMAGETARGET=official_images
+IMAGETARGET=bin-official_images
 
 # Set to 1 to save space by omitting the installation manual. 
 # If so the README will link to the manual on the web site.
@@ -292,7 +316,7 @@ export PUBLISH_PATH="/home/jigdo-area/"
 
 # Set to 1 to save space by omitting the release notes
 # If so we will link to them on the web site.
-export OMIT_RELEASE_NOTES=0
+export OMIT_RELEASE_NOTES=1
 
 # Set this to override the defaul location
 #export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
